package com.ruoyi.ems.service;

import java.util.List;
import com.ruoyi.ems.domain.CaMeterD;

/**
 * 碳计量日Service接口
 * 
 * @author ruoyi
 * @date 2024-08-12
 */
public interface ICaMeterDService
{
    /**
     * 查询碳计量日
     * 
     * @param id 碳计量日主键
     * @return 碳计量日
     */
     CaMeterD selectCaMeterDById(Long id);

    /**
     * 查询碳计量日列表
     * 
     * @param admEmsCaMeterD 碳计量日
     * @return 碳计量日集合
     */
     List<CaMeterD> selectCaMeterDList(CaMeterD caMeterD);

    /**
     * 新增碳计量日
     * 
     * @param caMeterD 碳计量日
     * @return 结果
     */
     int insertCaMeterD(CaMeterD caMeterD);

    /**
     * 修改碳计量日
     * 
     * @param caMeterD 碳计量日
     * @return 结果
     */
     int updateCaMeterD(CaMeterD caMeterD);

    /**
     * 批量删除碳计量日
     * 
     * @param ids 需要删除的碳计量日主键集合
     * @return 结果
     */
     int deleteCaMeterDByIds(Long[] ids);

    /**
     * 删除碳计量日信息
     * 
     * @param id 碳计量日主键
     * @return 结果
     */
     int deleteCaMeterDById(Long id);
}
